==> jc-1.4.0.tar.gz: soot/baf/PlaceholderInst.h <==
// public class soot.baf.PlaceholderInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class fff3ed50728d2779 soot_baf_PlaceholderInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_PlaceholderInst_H_
#define _JC_soot_baf_PlaceholderInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_baf_PlaceholderInst$sub_refs	_jc_soot_baf_PlaceholderInst$sub_refs;
typedef struct _jc_soot_baf_PlaceholderInst$sub_nonrefs	_jc_soot_baf_PlaceholderInst$sub_nonrefs;
typedef struct _jc_soot_baf_PlaceholderInst$refs	_jc_soot_baf_PlaceholderInst$refs;
typedef struct _jc_soot_baf_PlaceholderInst$nonrefs	_jc_soot_baf_PlaceholderInst$nonrefs;
typedef struct _jc_soot_baf_PlaceholderInst$object	_jc_soot_baf_PlaceholderInst$object;

typedef const struct _jc_soot_baf_PlaceholderInst$vmethods	_jc_soot_baf_PlaceholderInst$vmethods;
typedef const struct _jc_soot_baf_PlaceholderInst$vtable	_jc_soot_baf_PlaceholderInst$vtable;
typedef const struct _jc_soot_baf_PlaceholderInst$vtype	_jc_soot_baf_PlaceholderInst$vtype;

// Constructors
extern void _jc_soot_baf_PlaceholderInst$method$_init$9fbfbaac54ec3a82(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_baf_PlaceholderInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_PlaceholderInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
extern struct _jc_object *_jc_soot_baf_PlaceholderInst$method$getSource$255cc521242b3067(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_PlaceholderInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$getSource$255cc521242b3067;
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_baf_PlaceholderInst$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
	struct _jc_object	*(*getSource$255cc521242b3067)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *);
};

// Vtable
struct _jc_soot_baf_PlaceholderInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_PlaceholderInst$vmethods	soot_baf_PlaceholderInst;
};

// Vtype
struct _jc_soot_baf_PlaceholderInst$vtype {
	_jc_type			type;
	_jc_soot_baf_PlaceholderInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_PlaceholderInst$sub_refs {
	struct _jc_object	*source;
};

// Reference instance fields (object)
struct _jc_soot_baf_PlaceholderInst$refs {
    _jc_soot_baf_PlaceholderInst$sub_refs	soot_baf_PlaceholderInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_PlaceholderInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_PlaceholderInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_PlaceholderInst$sub_nonrefs	soot_baf_PlaceholderInst;
};

// Object instance structure
struct _jc_soot_baf_PlaceholderInst$object {
	_jc_soot_baf_PlaceholderInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_PlaceholderInst$vtype	*vtype;
	_jc_soot_baf_PlaceholderInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_PlaceholderInst$vtype _jc_soot_baf_PlaceholderInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_PlaceholderInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_PlaceholderInst$class_object;

#endif	/* _JC_soot_baf_PlaceholderInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/PlaceholderInst.h <==
// public class soot.baf.PlaceholderInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class fff3ed50728d2779 soot_baf_PlaceholderInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_PlaceholderInst_H_
#define _JC_soot_baf_PlaceholderInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_baf_PlaceholderInst$sub_refs	_jc_soot_baf_PlaceholderInst$sub_refs;
typedef struct _jc_soot_baf_PlaceholderInst$sub_nonrefs	_jc_soot_baf_PlaceholderInst$sub_nonrefs;
typedef struct _jc_soot_baf_PlaceholderInst$refs	_jc_soot_baf_PlaceholderInst$refs;
typedef struct _jc_soot_baf_PlaceholderInst$nonrefs	_jc_soot_baf_PlaceholderInst$nonrefs;
typedef struct _jc_soot_baf_PlaceholderInst$object	_jc_soot_baf_PlaceholderInst$object;

typedef const struct _jc_soot_baf_PlaceholderInst$vmethods	_jc_soot_baf_PlaceholderInst$vmethods;
typedef const struct _jc_soot_baf_PlaceholderInst$vtable	_jc_soot_baf_PlaceholderInst$vtable;
typedef const struct _jc_soot_baf_PlaceholderInst$vtype	_jc_soot_baf_PlaceholderInst$vtype;

// Constructors
extern void _jc_soot_baf_PlaceholderInst$method$_init$9fbfbaac54ec3a82(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_baf_PlaceholderInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_PlaceholderInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_PlaceholderInst$method$getSource$255cc521242b3067(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_PlaceholderInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$getSource$255cc521242b3067;
extern _jc_method _jc_soot_baf_PlaceholderInst$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_baf_PlaceholderInst$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSource$255cc521242b3067)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_PlaceholderInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_PlaceholderInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_PlaceholderInst$vmethods	soot_baf_PlaceholderInst;
};

// Vtype
struct _jc_soot_baf_PlaceholderInst$vtype {
	_jc_type			type;
	_jc_soot_baf_PlaceholderInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_PlaceholderInst$sub_refs {
	struct _jc_object	*source;
};

// Reference instance fields (object)
struct _jc_soot_baf_PlaceholderInst$refs {
    _jc_soot_baf_PlaceholderInst$sub_refs	soot_baf_PlaceholderInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_PlaceholderInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_PlaceholderInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_PlaceholderInst$sub_nonrefs	soot_baf_PlaceholderInst;
};

// Object instance structure
struct _jc_soot_baf_PlaceholderInst$object {
	_jc_soot_baf_PlaceholderInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_PlaceholderInst$vtype	*vtype;
	_jc_soot_baf_PlaceholderInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_PlaceholderInst$vtype _jc_soot_baf_PlaceholderInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_PlaceholderInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_PlaceholderInst$class_object;

#endif	/* _JC_soot_baf_PlaceholderInst_H_ */
